@@ -10,9 +10,9 @@
 
 #include "../kernel/mailkernel.h"
 #include "filter/mdnadvicedialog.h"
-#include "util/mailutil.h"
 #include "mailcommon_debug.h"
 #include "mdn/mdnadvicehelper.h"
+#include "util/mailutil.h"
 
 #include <MessageComposer/MessageFactoryNG>
 #include <MessageComposer/MessageSender>
@@ -61,7 +61,7 @@ FilterAction *FilterAction::newAction()
 
 QWidget *FilterAction::createParamWidget(QWidget *parent) const
 {
-    QWidget *w = new QWidget(parent);
+    auto w = new QWidget(parent);
     w->setObjectName(QStringLiteral("empty_widget"));
     return w;
 }
@@ -80,7 +80,7 @@ void FilterAction::clearParamWidget(QWidget *) const
 
 bool FilterAction::argsFromStringInteractive(const QString &argsStr, const QString &filterName)
 {
-    Q_UNUSED(filterName);
+    Q_UNUSED(filterName)
     argsFromString(argsStr);
     return false;
 }
