@@ -1,37 +1,26 @@
 /*
-  Copyright (c) 2013-2019 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-only
 */
 
 #include "filtertestkernel.h"
 
+#include <AkonadiCore/changerecorder.h>
+#include <AkonadiCore/entitymimetypefiltermodel.h>
+#include <AkonadiCore/entitytreemodel.h>
+#include <AkonadiCore/session.h>
 #include <KIdentityManagement/kidentitymanagement/identitymanager.h>
+#include <KSharedConfig>
 #include <MessageComposer/AkonadiSender>
 #include <mailcommon/foldercollectionmonitor.h>
-#include <AkonadiCore/session.h>
-#include <AkonadiCore/entitytreemodel.h>
-#include <AkonadiCore/entitymimetypefiltermodel.h>
-#include <AkonadiCore/changerecorder.h>
-#include <KSharedConfig>
 
 FilterTestKernel::FilterTestKernel(QObject *parent)
     : QObject(parent)
 {
     mMessageSender = new MessageComposer::AkonadiSender(this);
     mIdentityManager = new KIdentityManagement::IdentityManager(true, this);
-    Akonadi::Session *session = new Akonadi::Session("Filter Kernel ETM", this);
+    auto session = new Akonadi::Session("Filter Kernel ETM", this);
     mFolderCollectionMonitor = new MailCommon::FolderCollectionMonitor(session, this);
 
     mEntityTreeModel = new Akonadi::EntityTreeModel(folderCollectionMonitor(), this);
@@ -94,8 +83,8 @@ bool FilterTestKernel::showPopupAfterDnD()
 
 void FilterTestKernel::expunge(Akonadi::Collection::Id col, bool sync)
 {
-    Q_UNUSED(col);
-    Q_UNUSED(sync);
+    Q_UNUSED(col)
+    Q_UNUSED(sync)
 }
 
 qreal FilterTestKernel::closeToQuotaThreshold()
@@ -123,5 +112,5 @@ Akonadi::Collection::Id FilterTestKernel::lastSelectedFolder()
 
 void FilterTestKernel::setLastSelectedFolder(Akonadi::Collection::Id col)
 {
-    Q_UNUSED(col);
+    Q_UNUSED(col)
 }
