@@ -347,7 +347,7 @@ QDataStream &SearchPattern::operator>>(QDataStream &s) const
         break;
     }
 
-    for (const SearchRule::Ptr &rule : qAsConst(*this)) {
+    for (const SearchRule::Ptr &rule : std::as_const(*this)) {
         *rule >> s;
     }
     return s;
