@@ -1,19 +1,7 @@
 /*
-  Copyright (c) 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef SEARCHRULE_H
 #define SEARCHRULE_H
@@ -24,7 +12,8 @@
 #include <AkonadiCore/Item>
 
 class KConfigGroup;
-namespace MailCommon {
+namespace MailCommon
+{
 /**
  * @short This class represents one search pattern rule.
  * Incoming mail is sent through the list of mail filter
@@ -38,7 +27,7 @@ public:
     /**
      * Defines a pointer to a search rule.
      */
-    typedef std::shared_ptr<SearchRule> Ptr;
+    using Ptr = std::shared_ptr<SearchRule>;
 
     /**
      * Describes operators for comparison of field and contents.
@@ -78,8 +67,8 @@ public:
      * @brief Possible required parts.
      */
     enum RequiredPart {
-        Envelope = 0,   ///< Envelope
-        Header,         ///< Header
+        Envelope = 0, ///< Envelope
+        Header, ///< Header
         CompleteMessage ///< Whole message
     };
 
@@ -242,8 +231,8 @@ public:
      */
     virtual void addQueryTerms(Akonadi::SearchTerm &groupTerm, bool &emptyIsNotAnError) const
     {
-        Q_UNUSED(groupTerm);
-        Q_UNUSED(emptyIsNotAnError);
+        Q_UNUSED(groupTerm)
+        Q_UNUSED(emptyIsNotAnError)
     }
 
     QDataStream &operator>>(QDataStream &) const;
@@ -263,8 +252,6 @@ protected:
      */
     Akonadi::SearchTerm::Condition akonadiComparator() const;
 
-protected:
-    QString quote(const QString &content) const;
 private:
     static Function configValueToFunc(const char *);
     static QString functionToString(Function);
