@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef RESOURCEREADCONFIGFILE_H
 #define RESOURCEREADCONFIGFILE_H
 
+#include "mailcommon_export.h"
 #include <KConfigGroup>
 #include <QString>
-#include "mailcommon_export.h"
 
-namespace MailCommon {
+namespace MailCommon
+{
 class ResourceReadConfigFilePrivate;
 class MAILCOMMON_EXPORT ResourceReadConfigFile
 {
@@ -20,6 +21,7 @@ public:
     ~ResourceReadConfigFile();
 
     KConfigGroup group(const QString &name) const;
+
 private:
     ResourceReadConfigFilePrivate *const d;
 };
